#! /bin/sh

# Test pmldigital applied to images from a digital camera

tmpxml='tmp.xml'
../pmldigital -f 200*.jpg > $tmpxml
if [ "$1" = 's' ]; then
  ../pmlvalid $tmpxml 1>/dev/null
else
  ../pmlvalid $tmpxml 1>&2
fi
es=$?
rm $tmpxml
exit $es
